@@ -13,11 +13,13 @@ class Client:
             url_server_tableau,
             user_name_tableau,
             password_tableau,
+            url_site
 
     ):
         self.url_server_tableau = url_server_tableau
         self.password_tableau = password_tableau
         self.user_name_tableau = user_name_tableau
+        self.url_site = url_site
         self.connect_to_server()
 
     def connect_to_server(
@@ -30,7 +32,7 @@ class Client:
         self.status_connection = False
         logging.info('try connect to server')
         try:
-            tableau_auth = TSC.TableauAuth(self.user_name_tableau, self.password_tableau)
+            tableau_auth = TSC.TableauAuth(self.user_name_tableau, self.password_tableau, self.url_site)
             self.server = TSC.Server(self.url_server_tableau, use_server_version=True)
             self.server_auth = self.server.auth.sign_in(tableau_auth)
             self.status_connection = True
@@ -39,36 +41,44 @@ class Client:
 
     def get_dashboard_id(
             self,
-            workbook_name
+            workbook_id
     ):
-        if self.status_connection:
-            with self.server_auth:
-                self.workbook_id = ''
-                all_datasource, all_pagination = self.server.workbooks.get()
-                for workbooks in all_datasource:
-                    if workbooks.name == workbook_name:
-                        self.workbook_id = workbooks.id
-                        # self.workbook = self.server.workbooks.get_by_id(self.workbook_id)
-                        # logging.info([view.name for view in self.workbook.views])
-            if self.workbook_id == '':
-                    logging.info('Dashboard '+workbook_name +' not found on server')
+        try:
+            workbook_id = int(workbook_id)
+
+            if self.status_connection:
+                with self.server_auth:
+                    self.workbook_id = 0
+                    self.workbook_name = ''
+                    all_datasource, all_pagination = self.server.workbooks.get()
+                    for workbooks in all_datasource:
+                        if int(workbooks.webpage_url.split('/')[5]) == workbook_id:
+                            self.workbook_id =workbooks.id
+                            self.workbook_name =workbooks.name
+                        # logging.info(workbooks.name)
+                if self.workbook_id == 0:
+                    logging.info('Dashboard id ' + workbook_id + ' not found on server')
+        except:
+            self.workbook_id =0
+            logging.info('Workbook id must be numeric')
 
     def dashboard_refresh(
-        self,
-        workbook_name
+            self,
+            workbook_id
     ):
         """
         start jobs extract refresh for dashboard
         """
         self.connect_to_server()
-        self.get_dashboard_id(workbook_name)
-        if self.workbook_id != '':
-            with self.server_auth:
-                try:
-                    result = self.server.workbooks.refresh(self.workbook_id)
-                    logging.info('Dashboard start updating on '+str(result.created_at))
-                except:
-                    logging.info('Dashboard extract refresh is already starting')
+        if self.status_connection:
+            self.get_dashboard_id(workbook_id)
+            if self.workbook_id != 0:
+                with self.server_auth:
+                    try:
+                        result = self.server.workbooks.refresh(self.workbook_id)
+                        logging.info('Dashboard start updating on '+str(result.created_at))
+                    except:
+                        logging.info('Dashboard '+self.workbook_name +' extract refresh is already starting')
 
     def view_to_csv(
             self,
@@ -82,7 +92,7 @@ class Client:
         self.get_dashboard_id(workbook_name)
         self.connect_to_server()
         is_found = False
-        if self.workbook_id != '':
+        if self.workbook_id > 0:
             with self.server_auth:
                 try:
                     workbook = self.server.workbooks.get_by_id(self.workbook_id)
@@ -96,5 +106,4 @@ class Client:
                     if is_found == False:
                         logging.info('View ' + sheet_name +' not found in workbook '+workbook_name)
                 except:
-                    logging.info('Error!')
-
+                    logging.info('Error!')
\ No newline at end of file
